@@ -1,19 +1,18 @@
 /*
     Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+    This program is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KDAV_DAVCOLLECTIONSMULTIFETCHJOB_H
@@ -26,7 +25,11 @@
 
 #include <KJob>
 
+#include <memory>
+
 namespace KDAV {
+class DavCollectionsMultiFetchJobPrivate;
+
 /**
  * @short A job that fetches all DAV collection.
  *
@@ -48,6 +51,7 @@ public:
      * @param parent The parent object.
      */
     explicit DavCollectionsMultiFetchJob(const DavUrl::List &urls, QObject *parent = nullptr);
+    ~DavCollectionsMultiFetchJob();
 
     /**
      * Starts the job.
@@ -70,9 +74,8 @@ Q_SIGNALS:
 
 private:
     void davJobFinished(KJob *);
-    DavUrl::List mUrls;
-    DavCollection::List mCollections;
-    int mSubJobCount = -1;
+
+    const std::unique_ptr<DavCollectionsMultiFetchJobPrivate> d;
 };
 }
 
